==> apache-camel-4.2.0-src.zip: apache-camel-4.2.0/core/camel-core-model/src/main/java/org/apache/camel/model/WhenSkipSendToEndpointDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model;

import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlTransient;

import org.apache.camel.model.language.ExpressionDefinition;
import org.apache.camel.spi.AsPredicate;
import org.apache.camel.spi.Metadata;

/**
 * Predicate to determine if the message should be sent or not to the endpoint, when using interceptSentToEndpoint.
 */
@Metadata(label = "configuration")
@AsPredicate
@XmlRootElement(name = "whenSkipSendToEndpoint")
@XmlTransient // do not output in XSD as this is only used in a special "hack" for intercept
public class WhenSkipSendToEndpointDefinition extends WhenDefinition {

    @Override
    public String getShortName() {
        return "whenSkipSendToEndpoint";
    }

    /**
     * Expression used as the predicate to evaluate whether the message should be sent or not to the endpoint
     */
    @Override
    public void setExpression(ExpressionDefinition expression) {
        // override to include javadoc what the expression is used for
        super.setExpression(expression);
    }

}

==> apache-camel-4.8.9-src.zip: apache-camel-4.8.9/core/camel-core-model/src/main/java/org/apache/camel/model/WhenSkipSendToEndpointDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model;

import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlTransient;

import org.apache.camel.model.language.ExpressionDefinition;
import org.apache.camel.spi.AsPredicate;
import org.apache.camel.spi.Metadata;

/**
 * Predicate to determine if the message should be sent or not to the endpoint, when using interceptSentToEndpoint.
 */
@Metadata(label = "configuration")
@AsPredicate
@XmlRootElement(name = "whenSkipSendToEndpoint")
@XmlTransient // do not output in XSD as this is only used in a special "hack" for intercept
public class WhenSkipSendToEndpointDefinition extends WhenDefinition {

    public WhenSkipSendToEndpointDefinition() {
    }

    protected WhenSkipSendToEndpointDefinition(WhenSkipSendToEndpointDefinition source) {
        super(source);
    }

    @Override
    public WhenSkipSendToEndpointDefinition copyDefinition() {
        return new WhenSkipSendToEndpointDefinition(this);
    }

    @Override
    public String getShortName() {
        return "whenSkipSendToEndpoint";
    }

    /**
     * Expression used as the predicate to evaluate whether the message should be sent or not to the endpoint
     */
    @Override
    public void setExpression(ExpressionDefinition expression) {
        // override to include javadoc what the expression is used for
        super.setExpression(expression);
    }

}
